from setuptools import setup

setup(name='jp_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['jp_distributions'],
      zip_safe=False,
      install_requires=['matplotlib'])
